function results=oliver_generations_sim(reps)
% Generation	Condition	Decision
% 
% Condition:
% 1=free
% 2=voting
% 3=T40
% 4=T30
% 5=d7
% 6=d6
% 7=partial free
% 8=partial voter

% load in the data
data=getDataInternal();

% initialize the array that will hold the results
results=zeros(100,7,4);

% step through each condition
for condition=1:7
    
    % pull out the data for the first generation of this condition
    firstGen=data(find(data(:,1)==1 & data(:,2)==condition),3);
    
    % ...all of all subsequent generations (which are identical from the
    % point of view of the subjects)
	otherGens=data(find(data(:,1)>1 & data(:,2)==condition),3);
    
    % If its the Partial condition (==7), there are two sets of decisions to
    % load, those of the free players, and those of the voting players (the
    % latter is stored in firstGen2 and otherGens2)
    if condition==7
        firstGen2=data(find(data(:,1)==1 & data(:,2)==condition+1),3);
        otherGens2=data(find(data(:,1)>1 & data(:,2)==condition+1),3);
    else
        firstGen2=[0];
        otherGens2=[0];
    end
    
    % Set T
    if condition==3
        T=40;
    elseif condition==4
        T=30;
    else
        T=50;
    end
    
    % Set delta
    if condition==5
        d=0.7;
    elseif condition==6
        d=0.6;
    else
        d=0.8;
    end
    
    % Set which kind of voting it is
    if condition==1
        voting=0;
    elseif condition==7
        voting=0.5;
    else
        voting=1;
    end
 
    
    % do 'reps' bootstrapping simulations using the current data and setup,
    % each lasting 100 generations
    rHere=simInternal(firstGen,otherGens,T,d,voting,reps,firstGen2,otherGens2);
      
    % go thru each generation and look at fraction of pools exhausted, plus
    % bootstrapped standard error.
    for g=1:100
        full=length(find(rHere(:,g)==2));
        exhausted=length(find(rHere(:,g)==1));
        results(g,condition,1)=full/(full+exhausted);
        results(g,condition,2)=sqrt(full/(full+exhausted) - (full/(full+exhausted))^2);
        results(g,condition,3)=full/length(rHere(:,g));
        results(g,condition,4)=sqrt(full/length(rHere(:,g)) - (full/length(rHere(:,g)))^2);
    end
        
end
    
    

function rHere=simInternal(firstGen,otherGens,T,d,voting,reps,firstGen2,otherGens2)
% if delta is small, run 100x more repetitions since you get fewer
% generations / less data from any given run
if d<0.8
    reps=reps*100;
end

% will store the results for this set of params
rHere=zeros(reps,100);  %2=full, 1=exhausted, 0=ended

% run each bootstrapping sim
for rep=1:reps

    % pool is initialized as full in generation 1
    full=1;
    gen=1;
    
    % gen 1 def gets full pool
    rHere(rep,1)=2;
    
    % see if gen 1 depletes pool
    overexploit= (sum(firstGen(ceil(rand(1,5)*(length(firstGen)))))*(voting==0) ...
            + 5*median(firstGen(ceil(rand(1,5)*(length(firstGen)))))*(voting==1) ...
            + (sum(firstGen(ceil(rand(1,2)*(length(firstGen)))))+3*median(firstGen2(ceil(rand(1,3)*(length(firstGen2))))))*(voting==0.5)) ...
            >T;
    
    % check to see if the pool continues on to the next generation
    while rand<d & gen<100
        gen=gen+1;
        
        % check if prev generation over-exploited
        if overexploit==1
            full=0;
        end
        
        % if the pool is empty, mark it 0
        if full==0
            rHere(rep,gen)=1;
        % otherwise, see what the current generation will do
        else
            rHere(rep,gen)=2;
            overexploit= (sum(otherGens(ceil(rand(1,5)*(length(otherGens)))))*(voting==0) ...
            + 5*median(otherGens(ceil(rand(1,5)*(length(otherGens)))))*(voting==1) ...
            + (sum(otherGens(ceil(rand(1,2)*(length(otherGens)))))+3*median(otherGens2(ceil(rand(1,3)*(length(otherGens2))))))*(voting==0.5)) ...
            >T;
        end
    end
    rHere(rep,gen+1:100)=0;
end

    
function data=getDataInternal()
% Loads in the below data, which contains all of the individual decisions.
% Col 1 = condition (see key above)
% Col 2 = generation
% Col 3 = decision
data=[
1	1	15
1	1	20
1	1	20
1	1	20
1	1	10
1	1	6
1	1	5
1	1	20
1	1	9
1	1	20
1	1	3
1	1	10
1	1	10
1	1	20
1	1	10
1	1	10
1	1	7
1	1	10
1	1	5
1	1	10
1	1	10
1	1	15
1	1	5
1	1	20
1	1	20
1	1	10
1	1	20
1	1	5
1	1	10
1	1	10
1	1	4
1	1	10
1	1	0
1	1	5
1	1	9
1	1	5
1	1	20
1	1	10
1	1	10
1	1	10
1	1	12
1	1	20
1	1	20
1	1	20
1	1	7
1	1	20
1	1	8
1	1	1
1	1	20
1	1	10
1	1	20
1	1	20
1	1	20
1	1	10
1	1	10
1	1	20
1	1	20
1	1	10
1	1	8
1	1	7
1	1	20
1	1	1
1	1	10
1	1	4
1	1	20
1	1	10
1	1	20
1	1	3
1	1	15
1	1	4
1	1	10
1	1	10
1	1	10
1	1	5
1	1	20
1	1	10
1	1	8
1	1	15
1	1	20
1	1	6
1	1	4
1	1	3
1	1	7
1	1	10
1	1	5
1	1	15
1	1	6
1	1	20
1	1	9
1	1	8
1	1	9
1	1	5
1	1	5
1	1	10
1	1	10
1	1	10
1	1	10
1	1	10
1	1	20
1	1	20
2	1	20
2	1	9
2	1	10
2	1	7
2	1	10
2	1	8
2	1	20
2	1	20
2	1	20
2	1	10
2	1	8
2	1	7
2	1	7
2	1	8
2	1	10
2	1	8
2	1	8
2	1	7
2	1	10
2	1	7
3	1	20
3	1	20
3	1	10
3	1	5
3	1	20
3	1	10
3	1	8
3	1	10
3	1	8
3	1	20
1	2	10
1	2	10
1	2	9
1	2	20
1	2	20
1	2	9
1	2	10
1	2	20
1	2	5
1	2	10
1	2	10
1	2	10
1	2	5
1	2	10
1	2	8
1	2	10
1	2	10
1	2	4
1	2	10
1	2	8
1	2	10
1	2	10
1	2	10
1	2	20
1	2	5
1	2	5
1	2	8
1	2	20
1	2	10
1	2	10
1	2	4
1	2	8
1	2	5
1	2	9
1	2	9
1	2	10
1	2	10
1	2	6
1	2	10
1	2	10
1	2	3
1	2	10
1	2	0
1	2	10
1	2	9
1	2	10
1	2	10
1	2	7
1	2	10
1	2	20
1	2	2
1	2	10
1	2	10
1	2	5
1	2	20
1	2	10
1	2	10
1	2	6
1	2	15
1	2	10
1	2	10
1	2	7
1	2	10
1	2	10
1	2	8
1	2	10
1	2	20
1	2	4
1	2	10
1	2	5
1	2	10
1	2	7
1	2	9
1	2	5
1	2	10
1	2	10
1	2	20
1	2	7
1	2	9
1	2	14
1	2	7
1	2	10
1	2	2
1	2	20
1	2	10
1	2	10
1	2	9
1	2	10
1	2	5
1	2	3
1	2	5
1	2	10
1	2	10
1	2	9
1	2	9
1	2	7
1	2	10
1	2	10
1	2	10
1	2	5
2	2	7
2	2	2
2	2	18
2	2	10
2	2	5
2	2	4
2	2	5
2	2	6
2	2	20
2	2	9
2	2	5
2	2	9
2	2	20
2	2	1
2	2	10
2	2	6
2	2	8
2	2	4
2	2	10
2	2	9
2	2	4
2	2	9
2	2	7
2	2	10
2	2	8
2	2	9
2	2	5
2	2	5
2	2	10
2	2	10
2	2	20
2	2	9
2	2	6
2	2	20
2	2	7
2	2	5
2	2	7
2	2	8
2	2	10
2	2	5
2	2	10
2	2	9
2	2	5
2	2	10
2	2	8
2	2	4
2	2	10
2	2	10
2	2	7
2	2	10
2	2	10
2	2	10
2	2	20
2	2	8
2	2	10
2	2	1
2	2	9
2	2	10
2	2	5
2	2	8
2	2	7
2	2	10
2	2	5
2	2	20
2	2	8
2	2	10
2	2	6
2	2	9
2	2	8
2	2	10
2	2	2
2	2	9
2	2	5
2	2	9
2	2	4
2	2	10
2	2	10
2	2	9
2	2	8
2	2	20
3	2	20
3	2	9
3	2	9
3	2	7
3	2	10
3	2	8
3	2	5
3	2	5
3	2	15
3	2	9
3	2	10
3	2	20
3	2	10
3	2	7
3	2	5
3	2	15
3	2	10
3	2	9
3	2	10
3	2	10
3	2	10
3	2	10
3	2	10
3	2	20
3	2	10
3	2	8
3	2	20
3	2	1
3	2	5
3	2	10
3	2	10
3	2	12
3	2	9
3	2	9
3	2	10
3	2	9
3	2	5
3	2	9
3	2	7
3	2	4
3	2	10
3	2	10
3	2	8
3	2	8
3	2	10
3	2	2
3	2	7
3	2	6
3	2	10
3	2	6
3	2	3
3	2	4
3	2	1
3	2	10
3	2	10
4	2	6
4	2	9
4	2	4
4	2	10
4	2	7
4	2	7
4	2	1
4	2	5
4	2	5
4	2	6
4	2	6
4	2	10
4	2	6
4	2	10
4	2	0
4	2	6
4	2	10
4	2	10
4	2	8
4	2	9
4	2	9
4	2	18
4	2	10
4	2	10
4	2	7
4	2	10
4	2	8
4	2	4
4	2	20
4	2	10
4	2	10
4	2	5
4	2	14
4	2	10
4	2	5
4	2	10
4	2	8
4	2	5
4	2	5
4	2	10
4	2	20
4	2	20
4	2	10
4	2	10
4	2	8
5	2	10
5	2	10
5	2	7
5	2	6
5	2	10
5	2	20
5	2	10
5	2	10
5	2	10
5	2	9
5	2	10
5	2	3
5	2	10
5	2	9
5	2	10
5	2	10
5	2	10
5	2	10
5	2	10
5	2	9
5	2	1
5	2	1
5	2	10
5	2	5
5	2	8
5	2	10
5	2	11
5	2	20
5	2	9
5	2	9
5	2	7
5	2	10
5	2	14
5	2	9
5	2	20
5	2	5
5	2	5
5	2	10
5	2	8
5	2	10
6	2	20
6	2	5
6	2	9
6	2	10
6	2	8
6	2	8
6	2	8
6	2	10
6	2	5
6	2	9
7	2	4
7	2	10
7	2	10
7	2	12
7	2	9
7	2	20
7	2	9
7	2	7
7	2	20
7	2	10
8	2	9
8	2	10
8	2	8
8	2	5
8	2	9
8	2	20
8	2	5
8	2	5
8	2	5
8	2	10
9	2	9
9	2	7
9	2	1
9	2	10
9	2	10
10	2	7
10	2	20
10	2	9
10	2	8
10	2	9
11	2	10
11	2	20
11	2	9
11	2	10
11	2	10
12	2	10
12	2	10
12	2	9
12	2	8
12	2	20
1	3	8
1	3	6
1	3	7
1	3	7
1	3	20
1	3	11
1	3	8
1	3	3
1	3	5
1	3	8
1	3	8
1	3	20
1	3	4
1	3	7
1	3	10
1	3	7
1	3	20
1	3	8
1	3	7
1	3	8
1	3	8
1	3	3
1	3	8
1	3	8
1	3	8
1	3	2
1	3	8
1	3	8
1	3	20
1	3	20
1	3	6
1	3	4
1	3	7
1	3	8
1	3	6
1	3	7
1	3	8
1	3	3
1	3	8
1	3	4
1	3	7
1	3	8
1	3	0
1	3	8
1	3	5
1	3	20
1	3	20
1	3	8
1	3	7
1	3	6
1	3	8
1	3	4
1	3	6
1	3	3
1	3	3
1	3	10
1	3	5
1	3	11
1	3	5
1	3	8
1	3	7
1	3	8
1	3	5
1	3	8
1	3	10
1	3	5
1	3	8
1	3	3
1	3	8
1	3	8
1	3	8
1	3	20
1	3	2
1	3	5
1	3	20
1	3	7
1	3	5
1	3	6
1	3	8
1	3	8
1	3	8
1	3	20
1	3	7
1	3	8
1	3	7
1	3	7
1	3	8
1	3	8
1	3	8
1	3	5
1	3	8
1	3	4
1	3	5
1	3	15
1	3	8
1	3	7
1	3	5
1	3	8
1	3	20
1	3	6
2	3	20
2	3	5
2	3	7
2	3	20
2	3	5
2	3	20
2	3	8
2	3	6
2	3	8
2	3	7
2	3	5
2	3	6
2	3	5
2	3	8
2	3	8
2	3	5
2	3	0
2	3	10
2	3	8
2	3	20
2	3	20
2	3	8
2	3	8
2	3	7
2	3	7
2	3	8
2	3	8
2	3	7
2	3	6
2	3	5
2	3	5
2	3	9
2	3	5
2	3	8
2	3	3
2	3	3
2	3	20
2	3	5
2	3	8
2	3	6
2	3	7
2	3	5
2	3	6
2	3	4
2	3	20
2	3	9
2	3	7
2	3	8
2	3	8
2	3	2
2	3	9
2	3	5
2	3	8
2	3	20
2	3	8
2	3	8
2	3	4
2	3	5
2	3	17
2	3	5
2	3	1
2	3	5
2	3	4
2	3	6
2	3	8
2	3	5
2	3	8
2	3	7
2	3	8
2	3	4
2	3	0
2	3	6
2	3	7
2	3	20
2	3	1
2	3	5
2	3	5
2	3	3
2	3	5
2	3	8
3	3	6
3	3	8
3	3	8
3	3	5
3	3	8
3	3	8
3	3	20
3	3	5
3	3	7
3	3	5
3	3	8
3	3	8
3	3	1
3	3	20
3	3	8
3	3	8
3	3	8
3	3	6
3	3	8
3	3	1
3	3	6
3	3	10
3	3	8
3	3	20
3	3	8
3	3	7
3	3	20
3	3	4
3	3	20
3	3	8
3	3	8
3	3	7
3	3	5
3	3	8
3	3	20
3	3	8
3	3	8
3	3	8
3	3	4
3	3	5
3	3	20
3	3	5
3	3	20
3	3	8
3	3	6
3	3	2
3	3	7
3	3	8
3	3	10
3	3	8
3	3	8
3	3	9
3	3	7
3	3	8
3	3	6
3	3	8
3	3	2
3	3	8
3	3	8
3	3	7
3	3	8
3	3	6
3	3	8
3	3	7
3	3	8
3	3	7
3	3	9
3	3	7
3	3	2
3	3	8
3	3	7
3	3	8
3	3	8
3	3	7
3	3	7
4	3	8
4	3	20
4	3	5
4	3	8
4	3	6
4	3	6
4	3	20
4	3	9
4	3	7
4	3	15
4	3	6
4	3	8
4	3	20
4	3	8
4	3	4
4	3	3
4	3	7
4	3	5
4	3	8
4	3	5
4	3	6
4	3	5
4	3	7
4	3	8
4	3	8
4	3	5
4	3	5
4	3	4
4	3	8
4	3	5
4	3	8
4	3	8
4	3	6
4	3	8
4	3	20
4	3	8
4	3	8
4	3	7
4	3	20
4	3	8
4	3	4
4	3	8
4	3	8
4	3	3
4	3	7
4	3	20
4	3	8
4	3	1
4	3	8
4	3	8
4	3	8
4	3	8
4	3	8
4	3	1
4	3	8
4	3	7
4	3	7
4	3	8
4	3	8
4	3	5
4	3	8
4	3	5
4	3	8
4	3	5
4	3	8
4	3	8
4	3	5
4	3	8
4	3	7
4	3	6
4	3	6
4	3	20
4	3	4
4	3	8
4	3	20
5	3	3
5	3	6
5	3	15
5	3	6
5	3	20
5	3	8
5	3	6
5	3	8
5	3	8
5	3	8
5	3	7
5	3	5
5	3	8
5	3	4
5	3	10
5	3	3
5	3	8
5	3	10
5	3	8
5	3	8
5	3	7
5	3	6
5	3	20
5	3	20
5	3	8
5	3	8
5	3	7
5	3	4
5	3	10
5	3	5
5	3	8
5	3	7
5	3	8
5	3	5
5	3	20
5	3	8
5	3	8
5	3	20
5	3	8
5	3	5
5	3	14
5	3	10
5	3	20
5	3	8
5	3	7
5	3	6
5	3	8
5	3	8
5	3	8
5	3	20
6	3	8
6	3	2
6	3	12
6	3	4
6	3	6
6	3	7
6	3	8
6	3	5
6	3	6
6	3	10
6	3	8
6	3	4
6	3	7
6	3	8
6	3	5
6	3	2
6	3	0
6	3	8
6	3	8
6	3	7
6	3	7
6	3	8
6	3	6
6	3	7
6	3	6
6	3	8
6	3	6
6	3	20
6	3	3
6	3	5
7	3	8
7	3	20
7	3	15
7	3	8
7	3	6
7	3	5
7	3	10
7	3	8
7	3	7
7	3	9
7	3	6
7	3	8
7	3	8
7	3	8
7	3	8
7	3	20
7	3	8
7	3	5
7	3	8
7	3	1
7	3	5
7	3	15
7	3	4
7	3	7
7	3	15
8	3	9
8	3	2
8	3	6
8	3	5
8	3	7
8	3	4
8	3	1
8	3	8
8	3	7
8	3	8
8	3	9
8	3	6
8	3	8
8	3	10
8	3	8
8	3	5
8	3	7
8	3	20
8	3	5
8	3	8
9	3	8
9	3	10
9	3	20
9	3	20
9	3	20
9	3	10
9	3	20
9	3	8
9	3	8
9	3	10
9	3	8
9	3	8
9	3	6
9	3	4
9	3	5
9	3	8
9	3	10
9	3	20
9	3	8
9	3	6
10	3	3
10	3	6
10	3	7
10	3	8
10	3	2
10	3	8
10	3	8
10	3	8
10	3	7
10	3	8
11	3	7
11	3	8
11	3	8
11	3	20
11	3	6
11	3	8
11	3	20
11	3	8
11	3	7
11	3	6
12	3	7
12	3	8
12	3	7
12	3	6
12	3	20
12	3	10
12	3	9
12	3	20
12	3	8
12	3	5
13	3	8
13	3	8
13	3	8
13	3	2
13	3	8
1	4	6
1	4	4
1	4	5
1	4	5
1	4	20
1	4	3
1	4	6
1	4	5
1	4	5
1	4	20
1	4	6
1	4	6
1	4	6
1	4	11
1	4	6
1	4	5
1	4	6
1	4	10
1	4	20
1	4	6
1	4	3
1	4	4
1	4	6
1	4	3
1	4	5
1	4	6
1	4	3
1	4	5
1	4	5
1	4	5
1	4	20
1	4	4
1	4	1
1	4	6
1	4	5
1	4	20
1	4	7
1	4	6
1	4	5
1	4	20
1	4	3
1	4	6
1	4	5
1	4	5
1	4	5
1	4	6
1	4	5
1	4	6
1	4	6
1	4	20
1	4	4
1	4	5
1	4	4
1	4	7
1	4	4
1	4	1
1	4	6
1	4	4
1	4	2
1	4	7
1	4	6
1	4	5
1	4	6
1	4	5
1	4	5
1	4	4
1	4	6
1	4	6
1	4	6
1	4	5
1	4	3
1	4	6
1	4	5
1	4	20
1	4	6
1	4	6
1	4	3
1	4	2
1	4	10
1	4	6
1	4	5
1	4	6
1	4	6
1	4	20
1	4	5
1	4	6
1	4	20
1	4	6
1	4	6
1	4	1
1	4	20
1	4	1
1	4	6
1	4	4
1	4	6
1	4	1
1	4	5
1	4	5
1	4	20
1	4	5
2	4	2
2	4	5
2	4	5
2	4	20
2	4	6
2	4	20
2	4	7
2	4	6
2	4	10
2	4	6
2	4	6
2	4	5
2	4	20
2	4	5
2	4	2
2	4	5
2	4	5
2	4	6
2	4	5
2	4	20
2	4	20
2	4	5
2	4	5
2	4	20
2	4	6
2	4	2
2	4	5
2	4	1
2	4	6
2	4	20
2	4	6
2	4	3
2	4	15
2	4	6
2	4	5
2	4	1
2	4	2
2	4	5
2	4	5
2	4	6
2	4	4
2	4	5
2	4	5
2	4	6
2	4	20
2	4	5
2	4	6
2	4	20
2	4	5
2	4	5
2	4	20
2	4	20
2	4	20
2	4	5
2	4	2
2	4	20
2	4	4
2	4	7
2	4	6
2	4	1
2	4	6
2	4	4
2	4	20
2	4	4
2	4	1
2	4	5
2	4	6
2	4	7
2	4	5
2	4	6
2	4	5
2	4	5
2	4	1
2	4	6
2	4	20
3	4	20
3	4	6
3	4	5
3	4	5
3	4	5
3	4	6
3	4	5
3	4	20
3	4	5
3	4	3
3	4	5
3	4	6
3	4	6
3	4	20
3	4	20
3	4	4
3	4	5
3	4	3
3	4	7
3	4	20
3	4	5
3	4	20
3	4	6
3	4	4
3	4	20
3	4	20
3	4	6
3	4	6
3	4	5
3	4	3
3	4	6
3	4	6
3	4	6
3	4	6
3	4	6
3	4	20
3	4	6
3	4	6
3	4	5
3	4	6
3	4	5
3	4	6
3	4	20
3	4	6
3	4	6
3	4	20
3	4	6
3	4	4
3	4	5
3	4	4
3	4	4
3	4	6
3	4	4
3	4	8
3	4	20
3	4	6
3	4	6
3	4	5
3	4	5
3	4	20
4	4	2
4	4	20
4	4	20
4	4	6
4	4	5
4	4	2
4	4	6
4	4	5
4	4	5
4	4	4
4	4	5
4	4	8
4	4	6
4	4	4
4	4	6
4	4	8
4	4	12
4	4	2
4	4	6
4	4	5
4	4	3
4	4	5
4	4	6
4	4	3
4	4	5
4	4	6
4	4	3
4	4	20
4	4	4
4	4	4
4	4	20
4	4	6
4	4	6
4	4	6
4	4	6
4	4	4
4	4	5
4	4	6
4	4	5
4	4	6
4	4	6
4	4	6
4	4	6
4	4	5
4	4	4
4	4	7
4	4	1
4	4	5
4	4	6
4	4	6
5	4	3
5	4	5
5	4	3
5	4	5
5	4	4
5	4	7
5	4	4
5	4	4
5	4	6
5	4	5
5	4	10
5	4	6
5	4	20
5	4	3
5	4	4
5	4	3
5	4	4
5	4	6
5	4	4
5	4	5
5	4	6
5	4	5
5	4	6
5	4	3
5	4	6
5	4	6
5	4	20
5	4	7
5	4	20
5	4	2
5	4	5
5	4	5
5	4	5
5	4	5
5	4	5
5	4	10
5	4	20
5	4	5
5	4	6
5	4	20
6	4	5
6	4	6
6	4	20
6	4	5
6	4	3
6	4	6
6	4	9
6	4	5
6	4	20
6	4	5
6	4	6
6	4	20
6	4	5
6	4	5
6	4	20
6	4	5
6	4	5
6	4	5
6	4	7
6	4	6
6	4	3
6	4	9
6	4	20
6	4	5
6	4	6
7	4	4
7	4	20
7	4	7
7	4	6
7	4	20
1	5	5
1	5	20
1	5	10
1	5	8
1	5	6
1	5	8
1	5	7
1	5	5
1	5	1
1	5	8
1	5	10
1	5	20
1	5	10
1	5	5
1	5	10
1	5	10
1	5	2
1	5	4
1	5	10
1	5	4
1	5	20
1	5	10
1	5	10
1	5	10
1	5	4
1	5	10
1	5	10
1	5	9
1	5	10
1	5	8
1	5	9
1	5	6
1	5	10
1	5	10
1	5	9
1	5	8
1	5	7
1	5	3
1	5	10
1	5	6
1	5	7
1	5	20
1	5	20
1	5	6
1	5	3
1	5	7
1	5	9
1	5	9
1	5	8
1	5	10
1	5	2
1	5	1
1	5	5
1	5	5
1	5	5
1	5	5
1	5	5
1	5	5
1	5	10
1	5	10
1	5	10
1	5	8
1	5	20
1	5	6
1	5	9
1	5	20
1	5	14
1	5	8
1	5	20
1	5	10
1	5	10
1	5	20
1	5	10
1	5	10
1	5	20
1	5	10
1	5	8
1	5	15
1	5	6
1	5	7
1	5	5
1	5	10
1	5	9
1	5	10
1	5	10
1	5	3
1	5	10
1	5	5
1	5	20
1	5	7
1	5	7
1	5	10
1	5	3
1	5	10
1	5	20
1	5	8
1	5	5
1	5	10
1	5	10
1	5	10
2	5	10
2	5	9
2	5	10
2	5	10
2	5	5
2	5	5
2	5	10
2	5	10
2	5	10
2	5	10
2	5	8
2	5	9
2	5	10
2	5	9
2	5	5
2	5	5
2	5	9
2	5	2
2	5	6
2	5	10
2	5	10
2	5	8
2	5	10
2	5	9
2	5	8
2	5	5
2	5	5
2	5	10
2	5	8
2	5	9
2	5	10
2	5	10
2	5	10
2	5	10
2	5	10
2	5	10
2	5	20
2	5	3
2	5	10
2	5	10
2	5	8
2	5	9
2	5	8
2	5	9
2	5	10
2	5	20
2	5	0
2	5	10
2	5	0
2	5	10
2	5	10
2	5	10
2	5	8
2	5	9
2	5	3
2	5	20
2	5	20
2	5	10
2	5	7
2	5	9
2	5	9
2	5	7
2	5	10
2	5	10
2	5	9
2	5	9
2	5	8
2	5	5
2	5	4
2	5	10
3	5	9
3	5	10
3	5	10
3	5	10
3	5	7
3	5	8
3	5	9
3	5	5
3	5	10
3	5	5
3	5	20
3	5	20
3	5	20
3	5	8
3	5	8
3	5	20
3	5	8
3	5	10
3	5	10
3	5	20
3	5	10
3	5	10
3	5	9
3	5	10
3	5	10
3	5	10
3	5	10
3	5	8
3	5	9
3	5	10
3	5	10
3	5	10
3	5	9
3	5	9
3	5	10
3	5	11
3	5	10
3	5	4
3	5	10
3	5	20
4	5	10
4	5	20
4	5	9
4	5	10
4	5	8
4	5	4
4	5	9
4	5	9
4	5	8
4	5	9
4	5	10
4	5	10
4	5	10
4	5	9
4	5	8
4	5	4
4	5	10
4	5	10
4	5	10
4	5	9
4	5	10
4	5	10
4	5	10
4	5	10
4	5	10
4	5	10
4	5	5
4	5	10
4	5	10
4	5	10
4	5	10
4	5	4
4	5	8
4	5	9
4	5	10
5	5	9
5	5	5
5	5	20
5	5	9
5	5	10
5	5	10
5	5	10
5	5	7
5	5	20
5	5	7
5	5	10
5	5	10
5	5	5
5	5	10
5	5	6
5	5	8
5	5	7
5	5	20
5	5	10
5	5	7
5	5	10
5	5	10
5	5	10
5	5	8
5	5	10
5	5	6
5	5	5
5	5	6
5	5	8
5	5	10
6	5	20
6	5	9
6	5	10
6	5	9
6	5	20
6	5	10
6	5	20
6	5	10
6	5	8
6	5	10
6	5	9
6	5	4
6	5	10
6	5	7
6	5	4
6	5	8
6	5	10
6	5	10
6	5	5
6	5	5
7	5	5
7	5	9
7	5	7
7	5	5
7	5	20
7	5	20
7	5	4
7	5	10
7	5	15
7	5	7
8	5	20
8	5	6
8	5	10
8	5	8
8	5	15
8	5	15
8	5	7
8	5	5
8	5	15
8	5	5
9	5	8
9	5	5
9	5	5
9	5	10
9	5	10
9	5	20
9	5	9
9	5	5
9	5	10
9	5	6
10	5	7
10	5	8
10	5	8
10	5	5
10	5	10
11	5	9
11	5	10
11	5	5
11	5	20
11	5	7
12	5	12
12	5	10
12	5	6
12	5	9
12	5	7
13	5	8
13	5	10
13	5	10
13	5	10
13	5	9
1	6	10
1	6	6
1	6	7
1	6	10
1	6	6
1	6	9
1	6	9
1	6	10
1	6	1
1	6	10
1	6	8
1	6	20
1	6	6
1	6	10
1	6	8
1	6	9
1	6	9
1	6	7
1	6	9
1	6	4
1	6	10
1	6	1
1	6	10
1	6	0
1	6	6
1	6	10
1	6	10
1	6	5
1	6	9
1	6	10
1	6	10
1	6	10
1	6	10
1	6	20
1	6	7
1	6	6
1	6	10
1	6	10
1	6	7
1	6	10
1	6	20
1	6	6
1	6	10
1	6	10
1	6	10
1	6	10
1	6	7
1	6	9
1	6	8
1	6	10
1	6	9
1	6	10
1	6	7
1	6	5
1	6	6
1	6	20
1	6	5
1	6	7
1	6	5
1	6	10
1	6	12
1	6	10
1	6	20
1	6	1
1	6	20
1	6	10
1	6	10
1	6	5
1	6	20
1	6	4
1	6	10
1	6	6
1	6	12
1	6	7
1	6	9
1	6	10
1	6	12
1	6	10
1	6	10
1	6	7
1	6	9
1	6	10
1	6	7
1	6	5
1	6	5
1	6	10
1	6	10
1	6	7
1	6	1
1	6	10
1	6	12
1	6	7
1	6	10
1	6	10
1	6	8
1	6	9
1	6	4
1	6	10
1	6	10
1	6	20
2	6	10
2	6	1
2	6	10
2	6	7
2	6	4
2	6	10
2	6	8
2	6	10
2	6	9
2	6	9
2	6	10
2	6	3
2	6	5
2	6	7
2	6	5
2	6	8
2	6	6
2	6	10
2	6	10
2	6	7
2	6	10
2	6	10
2	6	5
2	6	1
2	6	5
2	6	10
2	6	10
2	6	7
2	6	6
2	6	5
2	6	7
2	6	10
2	6	10
2	6	5
2	6	6
2	6	10
2	6	9
2	6	10
2	6	20
2	6	10
2	6	9
2	6	10
2	6	10
2	6	20
2	6	10
2	6	8
2	6	11
2	6	8
2	6	7
2	6	9
2	6	7
2	6	8
2	6	6
2	6	4
2	6	9
2	6	12
2	6	4
2	6	9
2	6	7
2	6	10
2	6	4
2	6	10
2	6	10
2	6	10
2	6	10
3	6	20
3	6	8
3	6	10
3	6	10
3	6	8
3	6	20
3	6	10
3	6	9
3	6	10
3	6	20
3	6	20
3	6	20
3	6	20
3	6	5
3	6	20
3	6	8
3	6	8
3	6	20
3	6	7
3	6	7
3	6	10
3	6	10
3	6	10
3	6	6
3	6	10
3	6	3
3	6	10
3	6	10
3	6	10
3	6	10
3	6	8
3	6	9
3	6	10
3	6	8
3	6	7
3	6	8
3	6	10
3	6	10
3	6	9
3	6	10
4	6	20
4	6	8
4	6	5
4	6	6
4	6	10
4	6	10
4	6	5
4	6	12
4	6	20
4	6	10
4	6	8
4	6	20
4	6	10
4	6	6
4	6	3
4	6	10
4	6	8
4	6	6
4	6	20
4	6	9
4	6	7
4	6	8
4	6	8
4	6	10
4	6	10
4	6	9
4	6	20
4	6	10
4	6	5
4	6	8
5	6	10
5	6	10
5	6	2
5	6	20
5	6	5
5	6	20
5	6	9
5	6	10
5	6	10
5	6	9
5	6	20
5	6	20
5	6	2
5	6	10
5	6	9
5	6	20
5	6	5
5	6	9
5	6	7
5	6	10
6	6	5
6	6	10
6	6	10
6	6	5
6	6	20
6	6	4
6	6	20
6	6	6
6	6	7
6	6	15
6	6	6
6	6	10
6	6	6
6	6	9
6	6	10
7	6	10
7	6	9
7	6	10
7	6	10
7	6	10
8	6	2
8	6	10
8	6	12
8	6	3
8	6	6
1	7	8
1	7	6
1	7	0
1	7	5
1	7	10
1	7	5
1	7	20
1	7	20
1	7	8
1	7	7
1	7	5
1	7	6
1	7	10
1	7	5
1	7	9
1	7	8
1	7	7
1	7	1
1	7	5
1	7	7
1	7	4
1	7	5
1	7	10
1	7	10
1	7	15
1	7	6
1	7	5
1	7	20
1	7	20
1	7	10
1	7	9
1	7	8
1	7	8
1	7	10
1	7	10
1	7	10
1	7	14
1	7	5
1	7	0
1	7	8
2	7	12
2	7	20
2	7	6
2	7	5
2	7	10
2	7	10
2	7	10
2	7	20
2	7	3
2	7	6
2	7	7
2	7	12
2	7	20
2	7	5
2	7	5
2	7	12
2	7	5
2	7	6
2	7	14
2	7	12
3	7	6
3	7	6
3	7	10
3	7	10
3	7	10
3	7	10
3	7	8
3	7	5
3	7	20
3	7	5
4	7	20
4	7	6
4	7	20
4	7	5
4	7	9
4	7	5
4	7	8
4	7	10
5	7	8
5	7	8
5	7	10
5	7	20
6	7	5
6	7	10
7	7	5
7	7	2
8	7	1
8	7	9
9	7	10
9	7	5
1	8	10
1	8	5
1	8	13
1	8	10
1	8	5
1	8	0
1	8	10
1	8	9
1	8	15
1	8	7
1	8	7
1	8	6
1	8	12
1	8	10
1	8	8
1	8	4
1	8	9
1	8	3
1	8	20
1	8	20
1	8	7
1	8	20
1	8	5
1	8	9
1	8	8
1	8	10
1	8	6
1	8	7
1	8	9
1	8	8
1	8	8
1	8	9
1	8	9
1	8	15
1	8	10
1	8	8
1	8	9
1	8	5
1	8	10
1	8	12
1	8	8
1	8	9
1	8	10
1	8	10
1	8	20
1	8	3
1	8	9
1	8	5
1	8	10
1	8	8
1	8	1
1	8	5
1	8	10
1	8	10
1	8	20
1	8	12
1	8	9
1	8	12
1	8	20
1	8	20
2	8	9
2	8	8
2	8	9
2	8	9
2	8	10
2	8	5
2	8	5
2	8	10
2	8	13
2	8	2
2	8	8
2	8	8
2	8	16
2	8	20
2	8	6
2	8	7
2	8	5
2	8	9
2	8	5
2	8	10
2	8	3
2	8	7
2	8	10
2	8	5
2	8	7
2	8	5
2	8	10
2	8	9
2	8	8
2	8	15
3	8	7
3	8	9
3	8	10
3	8	10
3	8	20
3	8	10
3	8	1
3	8	10
3	8	10
3	8	9
3	8	7
3	8	10
3	8	7
3	8	5
3	8	5
4	8	10
4	8	4
4	8	10
4	8	8
4	8	10
4	8	11
4	8	15
4	8	10
4	8	8
4	8	9
4	8	11
4	8	9
5	8	10
5	8	8
5	8	9
5	8	9
5	8	6
5	8	20
6	8	10
6	8	3
6	8	10
7	8	20
7	8	10
7	8	10
8	8	9
8	8	7
8	8	5
9	8	10
9	8	8
9	8	9];













